==> linuxconf-tools-1.1.src.tar.gz: linuxconf-tools-1.1/projetx/prog.cc <==
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <misc.h>
#include "projet.h"
#include "projetx.m"

static char *tbprog[200];

/*
	Lit le fichier de correspondance nom-programmeur, numero
*/
static void near prog_readnum ()
{
	/* #Spcification: configuration / numro des programmeurs
		Les programmeurs clients de l'archive ont tous un numro
		d'identification. Le fichier prog.num contient
		la liste des programmeurs avec leur numro. C'est un
		fichier ASCII dont le format est:

			programmeur numro
			...
			programmeur numro

		Ce fichier est localis dans le rpertoire config de
		l'application. (Gnralement n:\projet\config).

		Le numro doit tre spcifi pour chaque programmeur. Ce
		numro est allou  vie. En principe, on ne devrait jamais
		limin de programmeur de ce fichier.

		On peut optionnellement plac un commentaire  la suite
		du numro dans le fichier. Gnralement, on placera le
		nom vritable du programmeur. Le programme ne se proccupe
		pas de ce qui suit le numro.
	*/
	static char is_init = 0;
	if (!is_init){
		char path[MAXSIZ_PATH];
		configPath.getval (path,sizeof(path));
		path_make (path,"prog.num",path);
		FILE *fin = fopen_err (path,"r",0);
		for (unsigned i=0; i<NB_ELM(tbprog); i++) tbprog[i] = NULL;
		tbprog[0] = strdup_err ("");	// Certaine fonction
										// assume que le programmeur 0
										// existe et est affichable.
		if (fin != NULL){
			char buf[300];
			while (fgets (buf,sizeof(buf)-1,fin)!=NULL){
				strip_end (buf);
				if (buf[0] != '\0'){
					char prog[50];
					int id;
					if (sscanf (buf,"%s %d",prog,&id)==2){
						if (tbprog[id] != NULL){
							xconf_error (MSG_U(E_PROGCONFLIT
								,"Les programmeur %s et %s\n"
								 "partage le mme numro d'identification %d")
								,tbprog[id],prog,id);
						}else{
							tbprog[id] = strdup_err (prog);
						}
					}else{
						xconf_error (MSG_U(E_PROGNUM
							,"La ligne %d du fichier %s\n"
							 "est invalide\n\n"
							 "%s\n\n"
							 "On attend un nom de programmeur\n"
							 "suivie de son numro d'identitication")
							,buf);
					}
				}
			}
			fclose (fin);
		}
		is_init = 1;
	}
}
/*
	Obtient le numro d'un programmeur.
	Pour des raisons de scurit et de paresse, la table n'est pas
	charger dynamiquement.
*/
int prog_getnum (const char *prog)
{
	int ret = -1;
	prog_readnum();
	for (unsigned no = 0; no < NB_ELM(tbprog); no++){
		if (tbprog[no] != NULL && stricmp(prog,tbprog[no])==0){
			ret = no;
			break;
		}
	}
	return ret;
}

/*
	Retourne le nom du programmeur associ  un numro
*/
const char *prog_num2str (int num)
{
	prog_readnum();
	const char *ret = "???";
	if (num >= 0 && num < (int)NB_ELM(tbprog)){
		ret = tbprog[num];
		if (ret == NULL) ret = " ";
	}else{
		bugapp_printf ("ADM/PROJET","prog_num2str num == %d ???\n",num);
	}
	return ret;
}

/*
	Obtient le nom (login) de l'usager.
	Retourne NULL si trouve pas.
*/
const char *prog_getname (
	int quit)	// Termine si trouve pas ?
{
	/* #Spcification: usager / identification
		On obtient le nom (login) de l'usager via la variable
		d'environnement VCSID. Si elle n'est pas dfinie, on utilise
		la variable USER.

		On aurait pue utiliser des mecanismes plus sophistique
		disponible avec les systemes d'exploitation (Novell, Unix).

		On l'a pas fait parce que ce n'est pas universellement
		disponible. Par exemple sur une machine DOS isolee n'a pas
		acces a ces fonctionnalit (login).

		Cela permet aussi de changer facilement d'identite pour
		raliser certaines acrobaties avec projetx.

		Le VCSID est historique. Ca provient de l'ancien systme
		d'archivage utilis  MKS durant la premire grande guerre
		(PVCS).

		Le USER provient de UNIX.
	*/
	char *prog = getenv("VCSID");
	if (prog == NULL) prog = getenv ("USER");
	if (prog == NULL){
		xconf_error (MSG_R(E_VCSID));
		if (quit) exit (-1);
	}
	return prog;
}

==> linuxconf-tools-1.6.src.tar.gz: linuxconf-tools-1.6/projetx/prog.cc <==
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <misc.h>
#include "projet.h"
#include "projetx.m"

static char *tbprog[200];

/*
	Lit le fichier de correspondance nom-programmeur, numero
*/
static void near prog_readnum ()
{
	/* #Spcification: configuration / numro des programmeurs
		Les programmeurs clients de l'archive ont tous un numro
		d'identification. Le fichier prog.num contient
		la liste des programmeurs avec leur numro. C'est un
		fichier ASCII dont le format est:

			programmeur numro
			...
			programmeur numro

		Ce fichier est localis dans le rpertoire config de
		l'application. (Gnralement n:\projet\config).

		Le numro doit tre spcifi pour chaque programmeur. Ce
		numro est allou  vie. En principe, on ne devrait jamais
		limin de programmeur de ce fichier.

		On peut optionnellement plac un commentaire  la suite
		du numro dans le fichier. Gnralement, on placera le
		nom vritable du programmeur. Le programme ne se proccupe
		pas de ce qui suit le numro.
	*/
	static char is_init = 0;
	if (!is_init){
		char path[MAXSIZ_PATH];
		configPath.getval (path,sizeof(path));
		path_make (path,"prog.num",path);
		FILE *fin = fopen_err (path,"r",0);
		for (unsigned i=0; i<NB_ELM(tbprog); i++) tbprog[i] = NULL;
		tbprog[0] = strdup_err ("");	// Certaine fonction
										// assume que le programmeur 0
										// existe et est affichable.
		if (fin != NULL){
			char buf[300];
			while (fgets (buf,sizeof(buf)-1,fin)!=NULL){
				strip_end (buf);
				if (buf[0] != '\0'){
					char prog[50];
					int id;
					if (sscanf (buf,"%s %d",prog,&id)==2){
						if (tbprog[id] != NULL){
							xconf_error (MSG_U(E_PROGCONFLIT
								,"Les programmeur %s et %s\n"
								 "partage le mme numro d'identification %d")
								,tbprog[id],prog,id);
						}else{
							tbprog[id] = strdup_err (prog);
						}
					}else{
						xconf_error (MSG_U(E_PROGNUM
							,"La ligne %d du fichier %s\n"
							 "est invalide\n\n"
							 "%s\n\n"
							 "On attend un nom de programmeur\n"
							 "suivie de son numro d'identitication")
							,buf);
					}
				}
			}
			fclose (fin);
		}
		is_init = 1;
	}
}
/*
	Obtient le numro d'un programmeur.
	Pour des raisons de scurit et de paresse, la table n'est pas
	charger dynamiquement.
*/
int prog_getnum (const char *prog)
{
	int ret = -1;
	prog_readnum();
	for (unsigned no = 0; no < NB_ELM(tbprog); no++){
		if (tbprog[no] != NULL && stricmp(prog,tbprog[no])==0){
			ret = no;
			break;
		}
	}
	return ret;
}

/*
	Retourne le nom du programmeur associ  un numro
*/
const char *prog_num2str (int num)
{
	prog_readnum();
	const char *ret = "???";
	if (num >= 0 && num < (int)NB_ELM(tbprog)){
		ret = tbprog[num];
		if (ret == NULL) ret = " ";
	}else{
		bugapp_printf ("ADM/PROJET","prog_num2str num == %d ???\n",num);
	}
	return ret;
}

/*
	Obtient le nom (login) de l'usager.
	Retourne NULL si trouve pas.
*/
const char *prog_getid (
	bool quit)	// Termine si trouve pas ?
{
	/* #Spcification: usager / identification
		On obtient le nom (login) de l'usager via la variable
		d'environnement PROJETX_ID. Si elle n'est pas dfinie, on utilise
		la variable USER.

		On aurait pue utiliser des mecanismes plus sophistique
		disponible avec les systemes d'exploitation (Novell, Unix).

		On l'a pas fait parce que ce n'est pas universellement
		disponible. Par exemple sur une machine DOS isolee n'a pas
		acces a ces fonctionnalit (login).

		Cela permet aussi de changer facilement d'identite pour
		raliser certaines acrobaties avec projetx.

		Le USER provient de UNIX.
	*/
	char *prog = getenv("PROJETX_ID");
	if (prog == NULL) prog = getenv ("USER");
	if (prog == NULL){
		xconf_error (MSG_U(E_USERID
			,"Incapable de vous identifier\n"
			 "La variable PROJETX_ID ou USER doit tre definie"));
		if (quit) exit (-1);
	}
	return prog;
}
